unit MabDlDlg;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, StdCtrls, Buttons;

type
  TdlgMabDelete = class(TForm)
    lblDelete: TLabel;
    imgDelete: TImage;
    btnYes: TBitBtn;
    btnNo: TBitBtn;
  private
    { Private declarations }
    FDescription: string;

    procedure SetButtonStyle(AButtonStyle: TButtonStyle);
  public
    { Public declarations }
    constructor Create(AOwner: TComponent);

    function Execute: Boolean;

    property ButtonStyle: TButtonStyle write SetButtonStyle;
    property Description: string read FDescription write FDescription;
  end;

   TMabDeleteDialog = class(TComponent)
   private
      { Private declarations }
      FButtonStyle: TButtonStyle;
      FCaption: string;
      FDescription: string;
      FFont: TFont;
      FParent: TForm;
      FParentFont: Boolean;

      procedure SetFont(AFont: TFont);
   protected
      { Protected declarations }
   public
      { Public declarations }
      constructor Create(AOwner: TComponent); override;

      function Execute: Boolean;
   published
      { Published declarations }
      property ButtonStyle: TButtonStyle read FButtonStyle write FButtonStyle
         default bsAutoDetect;
      property Caption: string read FCaption write FCaption;
      property Description: string read FDescription write FDescription;
      property Font: TFont read FFont write SetFont;
   end;

var
  dlgMabDelete: TdlgMabDelete;

implementation

{$R *.DFM}

constructor TdlgMabDelete.Create(AOwner: TComponent);
begin
   inherited Create(AOwner);

   FDescription := 'this item';
   if (Owner is TForm) then
   begin
      Font.Name := '';
      Font.Assign((Owner as TForm).Font);
   end;
end;

procedure TdlgMabDelete.SetButtonStyle(AButtonStyle: TButtonStyle);
begin
   btnYes.Style := AButtonStyle;
   btnNo.Style := AButtonStyle;
end;

function TdlgMabDelete.Execute: Boolean;
begin
   MessageBeep(MB_ICONQUESTION);
   lblDelete.Caption := 'Are you sure you want to delete ' + Description + '?';
   Result := (ShowModal = mrYes);
end;

constructor TMabDeleteDialog.Create(AOwner: TComponent);
begin
   inherited Create(AOwner);

   FButtonStyle := bsAutoDetect;
   FCaption := 'Confirm Delete';
   FDescription := '';

   FFont := TFont.Create;
   FFont.Name := 'MS Sans Serif';
   FFont.Size := 8;
   FFont.Color := clWindowText;
   FFont.Style := [];
end;

function TMabDeleteDialog.Execute: Boolean;
var
   dlgDelete: TdlgMabDelete;
begin
   Result := False;

   dlgDelete := TdlgMabDelete.Create(Owner);
   with dlgDelete do
      try
         ButtonStyle := Self.ButtonStyle;
         Caption     := Self.Caption;

         Font.Name := ' ';
         Font.Assign(Self.Font);
         if Self.Description <> '' then
            Description := Self.Description;

         Result := Execute;
      finally
         Free;
      end;
end;

procedure TMabDeleteDialog.SetFont(AFont: TFont);
begin
   if AFont <> FFont then
      FFont.Assign(AFont);
end;

end.
